# Generated by Django 3.2.11 on 2022-07-06 10:18

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "django_aws_api_gateway_websockets",
            "0002_rename_author_websocketsession_user",
        ),
    ]

    operations = [
        migrations.CreateModel(
            name="ApiGateway",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("api_name", models.CharField(max_length=255, unique=True)),
                (
                    "api_description",
                    models.CharField(blank=True, default="", max_length=255),
                ),
                (
                    "default_channel_name",
                    models.CharField(
                        blank=True,
                        default="",
                        help_text="Automatically sets the 'channel' on the WebSocketSession record for the connection",
                        max_length=128,
                    ),
                ),
                (
                    "domain_name",
                    models.CharField(
                        blank=True,
                        default="",
                        help_text="The full domain you wish to use for the API endpoint. E.G ws.example.com",
                        max_length=255,
                    ),
                ),
                (
                    "target_base_endpoint",
                    models.URLField(
                        blank=True,
                        default=None,
                        help_text="The URL on your website where the API Gateway routes will point, including the trailing /, but excluding the final route/slug portion of the URL. E.G. If your default route will point to https://www.example.com/ws/default then enter https://www.example.com/ws/",
                        null=True,
                    ),
                ),
                (
                    "certificate_arn",
                    models.CharField(
                        blank=True,
                        default="",
                        help_text="The ARN of the certificate to use from AWS Certificate Manager",
                        max_length=255,
                    ),
                ),
                (
                    "hosted_zone_id",
                    models.CharField(
                        blank=True,
                        default="",
                        help_text="The Hosted Zone ID from AWs Route 53 for the domain you wish to use",
                        max_length=32,
                    ),
                ),
                (
                    "api_key_selection_expression",
                    models.CharField(
                        default="$request.header.x-api-key", max_length=255
                    ),
                ),
                (
                    "route_selection_expression",
                    models.CharField(default="$request.body.action", max_length=255),
                ),
                ("route_key", models.CharField(default="$default", max_length=255)),
                (
                    "stage_name",
                    models.CharField(blank=True, default="production", max_length=63),
                ),
                (
                    "stage_description",
                    models.CharField(blank=True, default="", max_length=63),
                ),
                (
                    "tags",
                    models.JSONField(
                        blank=True,
                        default=dict,
                        help_text='In format {"tag-name": "tag-value"}',
                    ),
                ),
                (
                    "api_id",
                    models.CharField(
                        blank=True,
                        default="",
                        help_text="The ID of the Api Gateway returned by AWS",
                        max_length=32,
                    ),
                ),
                (
                    "api_endpoint",
                    models.CharField(
                        blank=True,
                        default="",
                        help_text="The Api Gateway endpoint",
                        max_length=255,
                    ),
                ),
                (
                    "api_gateway_domain_name",
                    models.CharField(
                        blank=True,
                        default="",
                        help_text="The value to point your CNAME record to",
                        max_length=255,
                    ),
                ),
                (
                    "api_mapping_id",
                    models.CharField(
                        blank=True,
                        default="",
                        help_text="The ApiMappingId to use with api_mapping calls",
                        max_length=128,
                    ),
                ),
                ("api_created", models.BooleanField(default=False, editable=False)),
                (
                    "custom_domain_created",
                    models.BooleanField(default=False, editable=False),
                ),
                ("created_on", models.DateTimeField(auto_now_add=True)),
                ("updated_on", models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.AddIndex(
            model_name="apigateway",
            index=models.Index(fields=["api_id"], name="django_aws__api_id_0da7ec_idx"),
        ),
        migrations.AddIndex(
            model_name="apigateway",
            index=models.Index(
                fields=["domain_name"], name="django_aws__domain__3b4423_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="apigateway",
            index=models.Index(
                fields=["custom_domain_created"], name="django_aws__custom__5e8390_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="apigateway",
            index=models.Index(
                fields=["api_created"], name="django_aws__api_cre_376add_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="apigateway",
            index=models.Index(
                fields=["created_on"], name="django_aws__created_32cf2a_idx"
            ),
        ),
        migrations.AddField(
            model_name="websocketsession",
            name="api_gateway",
            field=models.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="sessions",
                to="django_aws_api_gateway_websockets.apigateway",
            ),
        ),
    ]



# Generated by Django 3.2.11 on 2022-01-17 17:01

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("django_aws_api_gateway_websockets", "0001_initial"),
    ]

    operations = [
        migrations.RenameField(
            model_name="websocketsession",
            old_name="author",
            new_name="user",
        ),
    ]



from botocore import exceptions
from django.contrib import admin, messages
from django.contrib.admin import ModelAdmin, TabularInline

from django_aws_api_gateway_websockets import models


def create_api_gateway(modeladmin, request, queryset):
    """Creates the API Gateway record if one does not already exist"""
    for obj in queryset:
        if not obj.api_created:
            try:
                obj.create_gateway()
                messages.success(
                    request, f"API Gateway endpoint created for {obj.api_name}"
                )
            except exceptions.ClientError as ce:
                messages.error(
                    request, f"{str(ce)} occurred when processing {obj.api_name}"
                )


create_api_gateway.short_description = "Create API Gateway"


def create_custom_domain(modeladmin, request, queryset):
    """Creates the Custom Domain record if one does not already exist"""
    for obj in queryset:
        if obj.api_created and not obj.custom_domain_created:
            try:
                obj.create_custom_domain()
                messages.success(
                    request,
                    f"Custom Domain setup for {obj.api_name}. Next update DNS to point to {obj.api_gateway_domain_name}",
                )
            except exceptions.ClientError as ce:
                messages.error(
                    request, f"{str(ce)} occurred when processing {obj.api_name}"
                )


create_custom_domain.short_description = "Create Custom Domain record for the API"


class ApiGatewayAdditionalRouteInline(TabularInline):
    autocomplete_fields = ["api_gateway"]
    model = models.ApiGatewayAdditionalRoute

    def get_queryset(self, request):
        return super().get_queryset(request).select_related("api_gateway")


@admin.register(models.WebSocketSession)
class WebSocketSessionAdmin(ModelAdmin):
    search_fields = ["connection_id", "channel_name"]
    autocomplete_fields = ["user"]
    list_display = [
        "connection_id",
        "channel_name",
        "api_gateway",
        "user",
        "connected",
        "request_count",
        "created_on",
        "updated_on",
    ]
    list_filter = ["connected", "channel_name"]
    date_hierarchy = "created_on"

    def get_queryset(self, request):
        return super().get_queryset(request).select_related("user", "api_gateway")


@admin.register(models.ApiGateway)
class ApiGatewayAdmin(ModelAdmin):
    search_fields = ["domain_name", "api_name"]
    list_display = [
        "api_name",
        "domain_name",
        "default_channel_name",
        "api_id",
        "api_endpoint",
        "api_gateway_domain_name",
        "api_created",
        "custom_domain_created",
        "created_on",
        "updated_on",
    ]
    list_filter = ["api_created", "custom_domain_created"]
    actions = [create_api_gateway, create_custom_domain]
    date_hierarchy = "created_on"
    inlines = [
        ApiGatewayAdditionalRouteInline,
    ]

    def get_queryset(self, request):
        return super().get_queryset(request).prefetch_related("additional_routes")


@admin.register(models.ApiGatewayAdditionalRoute)
class ApiGatewayAdditionalRouteAdmin(ModelAdmin):
    autocomplete_fields = ["api_gateway"]
    search_fields = ["name", "key"]
    list_display = [
        "name",
        "api_gateway",
        "route_key",
        "integration_url",
    ]
    list_filter = ["api_gateway"]
    date_hierarchy = "created_on"

    def get_queryset(self, request):
        return super().get_queryset(request).select_related("api_gateway")
